searchData={"items":[{"type":"module","title":"LiveIsolatedComponent","doc":"Functions for testing LiveView stateful components in isolation easily.","ref":"LiveIsolatedComponent.html"},{"type":"macro","title":"LiveIsolatedComponent.assert_handle_event/4","doc":"Asserts that a given handle event has been received.\n\nDepending on the number of parameters, different parts are checked:\n\n- With no parameters, just that a handle_event message has been received.\n- With one parameter, just the event name is checked.\n- With two parameters, both event name and the parameters are checked.\n- The optional last argument is the timeout, defaults to 500 milliseconds\n\nIf you just want to check the parameters without checking the event name,\npass `nil` as the event name.","ref":"LiveIsolatedComponent.html#assert_handle_event/4"},{"type":"macro","title":"LiveIsolatedComponent.assert_handle_event_return/2","doc":"Asserts the return value of a handle_event","ref":"LiveIsolatedComponent.html#assert_handle_event_return/2"},{"type":"macro","title":"LiveIsolatedComponent.assert_handle_info/3","doc":"Asserts that a given handle_info event has been received.\n\nIf only the view is passed, only that a handle_info is received is checked.\nWith an optional event name, we check that too.\nThe third argument is an optional timeout, defaults to 500 milliseconds.","ref":"LiveIsolatedComponent.html#assert_handle_info/3"},{"type":"function","title":"LiveIsolatedComponent.live_assign/2","doc":"Updates the assigns of the component.\n\n    {:ok, view, _html} = live_isolated_component(SomeComponent, assigns: %{description: \"blue\"})\n\n    live_assign(view, %{description: \"red\"})","ref":"LiveIsolatedComponent.html#live_assign/2"},{"type":"function","title":"LiveIsolatedComponent.live_assign/3","doc":"Updates the key in assigns of the component.\n\n    {:ok, view, _html} = live_isolated_component(SomeComponent, assigns: %{description: \"blue\"})\n\n    live_assign(view, :description, \"red\")","ref":"LiveIsolatedComponent.html#live_assign/3"},{"type":"macro","title":"LiveIsolatedComponent.live_isolated_component/2","doc":"Renders the given component in isolation and live so you can tested like you would\ntest any LiveView.\n\nIt accepts the following options:\n  - `:assigns` accepts a map of assigns for the component.\n  - `:handle_event` accepts a handler for the `handle_event` callback in the LiveView.\n  - `:handle_info` accepts a handler for the `handle_info` callback in the LiveView.\n  - `:on_mount` accepts a list of either modules or tuples `{Module, parameter}`. See `Phoenix.LiveView.on_mount/1` for more info on the parameters.\n  - `:slots` accepts different slot descriptors.","ref":"LiveIsolatedComponent.html#live_isolated_component/2"},{"type":"macro","title":"More about slots - LiveIsolatedComponent.live_isolated_component/2","doc":"For defining slots, you need to use the `slot/2` macro. If you just pass a slot\nto `:slots`, it will be taken as a default sot (`@inner_block` inside the component).\n\nYou can also pass a map or keywords to `:slots`. In this case, the key is considered\nto be the slot name and the value, the different slots. Remember that the default slot's\nname is `inner_block`.\n\nFor passing multiple slots for the same name, you have two options:any()\n\n1. You can give an array of slots as the value in the map or the keywords.\n2. You can pass the same name multiple times with different slots. This option\n   is only available if you are using keywords, as this data structure preserves\n   all values.","ref":"LiveIsolatedComponent.html#live_isolated_component/2-more-about-slots"},{"type":"macro","title":"LiveIsolatedComponent.refute_handle_event/4","doc":"Refutes that a given handle event has been received.\n\nDepending on the number of parameters, different parts are checked:\n\n- With no parameters, just that a handle_event message has not been received.\n- With one parameter, just the event name is checked.\n- With two parameters, both event name and the parameters are checked.\n- The optional last argument is the timeout, defaults to 500 milliseconds\n\nIf you just want to check the parameters without checking the event name,\npass `nil` as the event name.","ref":"LiveIsolatedComponent.html#refute_handle_event/4"},{"type":"macro","title":"LiveIsolatedComponent.refute_handle_info/3","doc":"Asserts that a given handle_info event has not been received.\n\nIf only the view is passed, only that a handle_info is not received is checked.\nWith an optional event name, we check that too.\nThe third argument is an optional timeout, defaults to 500 milliseconds.","ref":"LiveIsolatedComponent.html#refute_handle_info/3"},{"type":"macro","title":"LiveIsolatedComponent.slot/2","doc":"Macro to define slots. Accepts a map or keywords and a block.\nThe block needs to return a template (use a `sigil_H`).\n\nThe arguments can be anything and they will be passed to the slot\nas attributes. There is only one special attribute that will not\nbe passed though:\n\n1. `let` behaves like in components, letting the component\n   pass some value into the slot.","ref":"LiveIsolatedComponent.html#slot/2"},{"type":"macro","title":"Example - LiveIsolatedComponent.slot/2","doc":"```\n> slot(let: {key, value}) do\n    ~H[\n     \n       Title coming from assigns:   \n       Key coming from let   \n       Value coming from let  \n     \n    ]\n  end\n```","ref":"LiveIsolatedComponent.html#slot/2-example"},{"type":"macro","title":"Conversion - LiveIsolatedComponent.slot/2","doc":"In case you are wondering how to convert a slot in HEEX\nto the slot macro, let's do a simple conversion from a\nnamed slot with attributes:any()\n\n```heex\n \n   Received value from parent component is   \n \n```\n\nFor converting this, we notice three different parts:\n\n1. The slot name. In this case, `:slot_name`.\n2. The slot attributes. In this case, `attr_1={5} attr_2=\"hola\" let={value}`.\n3. The slot content (or inner_block). In this case, the `span`.\n\nThus, we just need to pass to the `slots` options the following value (just\nshowing the keyword options to `live_isolated_component`):\n\n```elixir\n[\n  slots: [\n    slot_name: slot(attr_1: 5, attr_2: \"hola\", let: value) do\n      ~H[ Received value from parent component is   ]\n    end\n  ]\n]\n```","ref":"LiveIsolatedComponent.html#slot/2-conversion"},{"type":"extras","title":"Overview","doc":"# LiveIsolatedComponent\n\n![Elixir CI](https://github.com/Serabe/live_isolated_component/actions/workflows/elixir-ci.yml/badge.svg)\n\nThe simplest way to test a LiveView both stateful and function component in isolation\nwhile keeping the interactivity.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"> Version `0.7.0` drops support for some older versions of Elixir, OTP, Phoenix and Phoenix LiveView. This was done because the current CI matrix generated 24 different builds and just adding OTP 26 would mean duplicating that. Also, removing support for LiveView 0.18.16 drop some code.\n\n```elixir\ndef deps do\n  [\n    # If you are using OTP 25 or above, Elixir 1.14, Phoenix 1.7, LiveView 0.19:\n    {:live_isolated_component, \"~> 0.7.0\", only: [:dev, :test]}\n    # If you are in LV 0.18 or above\n    {:live_isolated_component, \"~> 0.6.5\", only: [:dev, :test]}\n    # If you are in LV 0.17\n    {:live_isolated_component, \"~> 0.5.2\", only: [:dev, :test]}\n  ]\nend\n```\n\nDocumentation can be found at [hexdocs](https://hexdocs.pm/live_isolated_component).","ref":"readme.html#installation"},{"type":"extras","title":"Basic usage - Overview","doc":"Importing `LiveIsolatedComponent` will import one function, `live_assign`, and a few macros. You can use `live_isolated_component` like you would use `live_isolated`, just pass the component you want to test as the first argument and use the options as you see fit. If you want to change the passed assigns from the test, use `live_assign` with the view instead of the socket.","ref":"readme.html#basic-usage"},{"type":"extras","title":"Example - Overview","doc":"Simple rendering:\n\n```elixir\n{:ok, view, _html} = live_isolated_component(SimpleButton)\n\nassert has_element?(view, \".count\", \"Clicked 0 times\")\n\nview\n  |> element(\"button\")\n  |> render_click()\n\nassert has_element?(view, \".count\", \"Clicked 1 times\")\n```\n\nTesting assigns:\n\n```elixir\n{:ok, view, _html} = live_isolated_component(Greeting, %{name: \"Sergio\"})\n\nassert has_element?(view, \".name\", \"Sergio\")\n\nlive_assign(view, :name, \"Fran\")\n# or\n# live_assign(view, name: \"Fran\")\n# or\n# live_assign(view, %{name: \"Fran\"})\n\nassert has_element?(view, \".name\", \"Fran\")\n```\n\nTesting `handle_event`:\n\n```elixir\n{:ok, view, _html} = live_isolated_component(SimpleButton,\n    assigns: %{on_click: :i_was_clicked}\n  )\n\nview\n  |> element(\"button\")\n  |> render_click()\n\nassert_handle_event view, :i_was_clicked\n```\n\nTesting `handle_info`:\n\n```elixir\n{:ok, view, _html} = live_isolated_component(ComplexButton,\n    assigns: %{on_click: :i_was_clicked}\n  )\n\nview\n  |> element(\"button\")\n  |> render_click()\n\nassert_handle_info view, :i_was_clicked\n```\n\n`handle_event` callback:\n\n```elixir\n{:ok, view, _html} = live_isolated_component(SimpleButton,\n    assigns: %{on_click: :i_was_clicked},\n    handle_event: fn :i_was_clicked, _params, socket ->\n      # Do something\n      {:noreply, socket}\n    end\n  )\n```\n\n`handle_info` callback:\n\n```elixir\n{:ok, view, _html} = live_isolated_component(SimpleButton,\n    assigns: %{on_click: :i_was_clicked},\n    handle_info: fn :i_was_clicked, _params, socket ->\n      # Do something\n      {:noreply, socket}\n    end\n  )\n```","ref":"readme.html#example"},{"type":"extras","title":"Slots - Overview","doc":"The `slots` options can be:\n\n1. Just a slot. In that case, it'd be taken as the default slot.\n2. A map or keywords. In this case, the keys are the name of the slots, the values\n   can either be a slot or an array of slots. In case of keywords, the values\n   will be collected for the same slot name.\n\n#","ref":"readme.html#slots"},{"type":"extras","title":"Defining a slot - Overview","doc":"We define slots by using the `slot` macro. This macro accepts a keyword list and a block.\nThe block needs to return a template (you can use `sigil_H`). The keywords will be considered\nattributes of the slot except for the following `let`:\n\n- `let` will bind the argument to the value. You can use destructuring here.\n\nLike in a real slot, the `assigns` the slot have access to is that of the parent LiveView.\n\n#","ref":"readme.html#defining-a-slot"},{"type":"extras","title":"Slot Examples - Overview","doc":"Just a default slot:\n\n```elixir\n{:ok, view, html} = live_isolated_component(MyComponent,\n  slots: slot(assigns: assigns) do\n    ~H[Hello from default slot]\n  end\n)\n```\n\nJust a default slot (map version):\n\n```elixir\n{:ok, view, html} = live_isolated_component(MyComponent,\n  slots: %{\n    inner_block: slot(assigns: assigns) do\n      ~H[Hello from default slot]\n    end\n  }\n)\n```\n\nNamed slot (only one slot defined):\n\n```elixir\n{:ok, view, html} = live_isolated_component(MyTableComponent,\n  slots: %{\n    col: slot(assigns: assigns, header: \"Column Header\") do\n      ~H[Hello from the column slot]\n    end\n  }\n)\n```\n\nNamed slot (multiple slots defined):\n\n```elixir\n{:ok, view, html} = live_isolated_component(MyTableComponent,\n  slots: %{\n    col: [\n      slot(assigns: assigns, let: item, header: \"Language\") do\n        ~H[ ]\n      end,\n      slot(assigns: assigns, let: %{greeting: greeting}, header: \"Greeting\") do\n        ~H[ ]\n      end\n    ]\n  }\n)\n```","ref":"readme.html#slot-examples"}],"content_type":"text/markdown"}